15.47. cdist-type__firewalld_start(7) — cdist 4.10.4 documentation

# 15.47. cdist-type__firewalld_start(7)

## 15.47.1. NAME

cdist-type__firewalld_start - start and enable firewalld

## 15.47.2. DESCRIPTION

This cdist type allows you to start and enable firewalld.

## 15.47.3. REQUIRED PARAMETERS

None

## 15.47.4. OPTIONAL PARAMETERS

startstate
  'present' or 'absent', start/stop firewalld. Default is 'present'.
bootstate
  'present' or 'absent', enable/disable firewalld on boot. Default is 'present'.

## 15.47.5. EXAMPLES

    # start and enable firewalld
    __firewalld_start

    # only enable firewalld to start on boot
    __firewalld_start --startstate present --bootstate absent

## 15.47.6. SEE ALSO

firewalld(8)

## 15.47.7. AUTHORS

Darko Poljak <darko.poljak--@--ungleich.ch>

## 15.47.8. COPYING

Copyright (C) 2016 Darko Poljak. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.